{
    # No Logger while testing
    modules_disable => ['Logger']
};
